# Python Custom Logger
A custom logger that you can use inside your projects

### Try It Out

```python

# named the lib after me: src -> drnerd1-logger
from src import logger

logger.debug("This debug word is cyan, rest is white")
logger.info("This info word is deep blue, rest is white")
logger.warning("This warning is yellow, rest is white")
logger.error("This error word is red, rest is white")
logger.critical("This critical error word is bold red, rest is white")
```
